@@ -23,7 +23,7 @@
 #define SSOCR2_DEFINES_H
 
 /* version number */
-#define VERSION "2.24.0"
+#define VERSION "2.24.1"
 
 /* states */
 #define FIND_DARK 0
@@ -187,7 +187,8 @@ typedef enum luminance_e {
   MAXIMUM,
   RED,
   GREEN,
-  BLUE
+  BLUE,
+  LUM_PARSE_ERROR
 } luminance_t;
 
 /* direction, to mirror horizontally or vertically, or for a scanline */
@@ -202,7 +203,8 @@ typedef enum charset_e {
   CS_DIGITS,
   CS_DECIMAL,
   CS_HEXADECIMAL,
-  CS_TT_ROBOT
+  CS_TT_ROBOT,
+  CS_PARSE_ERROR
 } charset_t;
 
 #define DEFAULT_CHARSET CS_FULL
