@@ -328,7 +328,7 @@ int main(int argc, char **argv)
       {"ascii-art-segments", 0, 0, 'S'}, /* print found segments in ASCII art */
       {"print-as-hex", 0, 0, 'X'}, /* change output format to hex */
       {"omit-decimal-point", 0, 0, 'C'}, /* omit decimal points from output */
-      {"charset", 1, 0, 'c'}, /* omit decimal points from output */
+      {"charset", 1, 0, 'c'}, /* select character set of display */
       {"dec-h-ratio", 1, 0, 'H'}, /* height ratio for decimal point detection */
       {"dec-w-ratio", 1, 0, 'W'}, /* width ratio for decimal point detection */
       {"print-spaces", 0, 0, 's'}, /* print spaces between distant digits */
@@ -532,6 +532,12 @@ int main(int argc, char **argv)
       case 'l':
         if(optarg) {
           lt = parse_lum(optarg);
+          if(lt == LUM_PARSE_ERROR) {
+            fprintf(stderr,
+                    PROG ": warning: ignoring unknown luminance formula '%s'\n",
+                    optarg);
+            lt = DEFAULT_LUM_FORMULA;
+          }
         }
         break;
       case 'S':
@@ -558,6 +564,11 @@ int main(int argc, char **argv)
       case 'c':
         if(optarg) {
           charset = parse_charset(optarg);
+          if(charset == CS_PARSE_ERROR) {
+            fprintf(stderr, PROG ": warning: ignoring unknown charset '%s'\n",
+                    optarg);
+            charset = DEFAULT_CHARSET;
+          }
         }
         break;
       case 'H':
@@ -1546,8 +1557,9 @@ int main(int argc, char **argv)
     }
   }
   if(!widest_dig_is_one) {
-    fputs(" widest digit is not a one, skipping extra decimal point search\n",
-          stderr);
+    if(flags & DEBUG_OUTPUT)
+      fputs(" widest digit is not a one, skipping extra decimal point search\n",
+            stderr);
   } else {
     /* widest digit is a one, thus decimal seperators may have been missed:
      * identify a decimal point (or thousands separator) by relative height */
